#!/bin/csh
# map.csh - makes RR and LL channel maps for DR21OH
# 

set SRC = dr21oh
#set REGION = 'arcsec,box(0,0,-6,6)'
set REGION = 'arcsec,box(10)'

set MAP = dust
set INOISE = 0.06
set QUNOISE = .001
set DEVICE = /xs

goto start

start:
    foreach WIN ( 11 13 15 )
      rm -r win$WIN.LL.mp win$WIN.RR.mp win$WIN.bm
      invert vis=../05aug2013/win$WIN.cal,../23aug2013/win$WIN.cal,../24aug2013/win$WIN.cal \
         map=win$WIN.RR.mp,win$WIN.LL.mp beam=win$WIN.bm line=chan,159,1,1 sup=0 options=systemp \
	     select='source('$SRC')' stokes=RR,LL cell=0.5 imsize=128
      implot in=win$WIN.bm region=quarter device=/xs conflag=np conargs=5
        $<
      foreach POL ( LL RR )
        rm -r win$WIN.$POL.sl
        clean map=win$WIN.$POL.mp beam=win$WIN.bm out=win$WIN.$POL.sl
        rm -r win$WIN.$POL.cm
        restor map=win$WIN.$POL.mp beam=win$WIN.bm model=win$WIN.$POL.sl out=win$WIN.$POL.cm
        cgdisp in=win$WIN.$POL.cm device=/xs options=3pixel csize=0,1 region=quarter labtyp=arcsec
        imspec in=win$WIN.$POL.cm region='arcsec,box(10)' device=/xs options=style,step
      end
    end

    foreach WIN ( 11 13 15 )
      foreach POL ( LL RR )
        imspec in=win$WIN.$POL.cm  region=$REGION log=win$WIN.$POL.spec
      end
    end
goto end

  # ================================
  # ====== Dust continuum map ====== 
  # ================================

    rm -r  $MAP.I.mp $MAP.Q.mp $MAP.U.mp $MAP.V.mp $MAP.bm
    invert vis=../05aug2013/wide.cal,../23aug2013/wide.cal,../24aug2013/wide.cal \
      line=chan,1,1,94 \
      map=$MAP.I.mp,$MAP.Q.mp,$MAP.U.mp,$MAP.V.mp beam=$MAP.bm stokes=I,Q,U,V sup=0 \
      'select=source('$SRC')' options=systemp cell=0.5 imsize=128

    rm noiseList
    foreach MP ($MAP.I $MAP.Q $MAP.U $MAP.V)
      rm -r $MP.sl
      clean map=$MP.mp beam=$MAP.bm out=$MP.sl niters=3000
      rm -r $MP.cm
      restor map=$MP.mp beam=$MAP.bm model=$MP.sl out=$MP.cm
      cgdisp in=$MP.cm device=/xs region='arcsec,box(-15,-15,15,15)' labtyp=arcsec
      echo " " >> noiseList
      echo $MP".cm" >> noiseList
      imlist options=stat in=$MP.cm region='arcsec,box(20,-20,-20,-5)' | tail -2 >> noiseList
      $<
    end
    tail -20 noiseList
goto end

# >>> edit INOISE and QUNOISE <<< #

start:
  # Plot contour images of Q and U on gray scale image of I 
    foreach DEVICE ( /xs $MAP.IQU.ps/cps )
      cgdisp in=$MAP.I.cm,$MAP.Q.cm,$MAP.U.cm type=pixel,contour,contour options=full \
        region=quarter labtyp=hms,dms cols1=2 cols2=4 slev=a,$QUNOISE,a,$QUNOISE \
        levs1=-15,-14,-13,-12,-11,-10,-9,-8,-7,-6,-5,-4,-3,3,4,5,6,7,8,9,10,11,12,13,14,15 \
        levs2=-15,-14,-13,-12,-11,-10,-9,-8,-7,-6,-5,-4,-3,3,4,5,6,7,8,9,10,11,12,13,14,15 \
        line=1,3,3 device=$DEVICE
     end
     $<

     rm -r $MAP.poli.cm $MAP.polm.cm $MAP.pa.cm
     impol poli=$MAP.poli.cm polm=$MAP.polm.cm pa=$MAP.pa.cm sigma=$QUNOISE,$INOISE \
       in=$MAP.Q.cm,$MAP.U.cm,$MAP.I.cm sncut=3,2

  # Plot polarization vectors on I contour map
    foreach DEVICE ( /xs $MAP.rot90.ps/cps )
      cgdisp in=$MAP.I.cm,$MAP.poli.cm,$MAP.pa.cm type=contour,amp,angle \
        region=quarter options=full,rot90 labtyp=hms,dms vecfac=1.2,4,4 beamtyp=b,l,4 \
        lines=1,1,10 cols1=1 slev=a,$INOISE \
        levs1=-6,-5,-4,-3,3,4,5,6,8,10,15,20,25,30,35,40,45,50,55 \
        device=$DEVICE
    end
goto end
 

end:
